@@ -12,7 +12,10 @@ from ._setable import *
 from ._note import *
 from ._offset import *
 from ._open import *
+from ._rename import *
 from ._setpoint import *
 from ._store import *
 from ._tune import *
 from ._tune_test import *
+from ._update_merge import *
+from .io import *
