@@ -14,6 +14,7 @@ class TransitionType(str, Enum):
     create = "create"
     read = "read"
     restore = "restore"
+    rename = "rename"
     offset_to = "offset_to"
     offset_by = "offset_by"
     map_limits = "map_limits"
@@ -22,6 +23,7 @@ class TransitionType(str, Enum):
     intensity = "intensity"
     setpoint = "setpoint"
     holistic = "holistic"
+    update_merge = "update_merge"
 
 
 class Transition:
@@ -32,6 +34,19 @@ class Transition:
         metadata: Optional[Dict[str, Any]] = None,
         data: Optional["wt.Data"] = None,
     ):
+        """Represent one processing step of an instrument.
+
+        Parameters
+        ----------
+        type: TransitionType
+            Indentity of the type of transition
+        previous: Optional["Instrument"]
+            The instrument which was modified in the transition.
+        metadata: Optional[Dict[str, Any]]
+            JSON serializable metadata associated with the transition.
+        data: Optional["wt.Data"]
+            A WrightTools Data object that was used to generate the transition.
+        """
         self.type = type
         self.previous = previous
         if metadata is None:
@@ -43,6 +58,7 @@ class Transition:
         return f"Transition({repr(self.type)}, {repr(self.previous)}, {repr(self.metadata)})"
 
     def as_dict(self) -> Dict[str, Any]:
+        """JSON serializable representation of the transition."""
         return {
             "type": self.type,
             "metadata": self.metadata,
